pub(crate) enum ContainingBlockCalculation<'a> {
Lazy {
layout_thread: &'a LayoutThread,
},
AlreadyDoneWithStackingContextTree,
}Expand description
A token which ensures the calculation and assignment of cumulative containing blocks to fragments in the fragment tree. This is used because these cumulative containing block offsets are set during stacking context tree construction, but some queries might need them beforehand. If the query is executed before stacking context tree construction, a quick traversal is performed to calculate them for the purpose of the query.
Variants
Lazy
This token variant is for the purpose of a layout query. In this case, if stacking context tree construction has not yet taken place, a cumulative containing block calculation traversal will be performed.
Fields
layout_thread: &'a LayoutThreadAlreadyDoneWithStackingContextTree
This token variant is used when the code can guarantee that stacking context tree construction has already taken place.
Note: Using this before stacking context tree construction can lead to incorrect layout or layout query results!
Implementations
Sourceimpl ContainingBlockCalculation<'_>
impl ContainingBlockCalculation<'_>