pub(crate) struct TextFragment {
pub base: BaseFragment,
pub run_data: Arc<SharedTextRunData>,
pub font_metrics: Arc<FontMetrics>,
pub font_key: FontInstanceKey,
pub glyphs: Vec<Arc<ShapedTextSlice>>,
pub justification_adjustment: Au,
pub character_range_in_dom_node: Range<Utf32CodeUnits>,
pub is_empty_for_text_cursor: bool,
}Fields
base: BaseFragmentrun_data: Arc<SharedTextRunData>font_metrics: Arc<FontMetrics>font_key: FontInstanceKeyglyphs: Vec<Arc<ShapedTextSlice>>justification_adjustment: AuExtra space to add for each justification opportunity.
character_range_in_dom_node: Range<Utf32CodeUnits>The range of characters this TextFragment represents within the text of its
original DOM node (modified by text transformation).
is_empty_for_text_cursor: boolWhether or not this TextFragment is an empty fragment added for the
benefit of placing a text cursor on an otherwise empty editable line.
Implementations
Sourceimpl TextFragment
impl TextFragment
pub(crate) fn style<'a>(&'a self) -> AtomicRef<'a, ServoArc<ComputedValues>>
pub(crate) fn selected_style<'a>( &'a self, ) -> AtomicRef<'a, ServoArc<ComputedValues>>
pub fn print(&self, tree: &mut PrintTree)
Sourcepub(crate) fn point_is_within_vertical_boundaries(
&self,
point_in_fragment: Point2D<Au, CSSPixel>,
) -> bool
pub(crate) fn point_is_within_vertical_boundaries( &self, point_in_fragment: Point2D<Au, CSSPixel>, ) -> bool
Whether or not the given point is within the vertical boundaries of this
TextFragment.
Sourcepub(crate) fn distance_to_point_for_glyph_offset(
&self,
point_in_fragment: Point2D<Au, CSSPixel>,
) -> Au
pub(crate) fn distance_to_point_for_glyph_offset( &self, point_in_fragment: Point2D<Au, CSSPixel>, ) -> Au
Find the distance between for point relative to a TextFragment for the
purposes of finding a glyph offset. This is used to identify the most relevant
fragment for glyph offset queries during click handling.
Sourcepub(crate) fn character_offset(
&self,
point_in_fragment: Point2D<Au, CSSPixel>,
) -> Option<Utf32CodeUnits>
pub(crate) fn character_offset( &self, point_in_fragment: Point2D<Au, CSSPixel>, ) -> Option<Utf32CodeUnits>
Given a point relative to this TextFragment, find the most appropriate
character offset.
Note that the given point may be outside the TextFragment’s content rect:
- If the point is vertically above the
TextFragmentthe first offset will be returned. - If the point is vertically below the
TextFragment,Nonewill be returned.
Sourcefn unmapped_character_offset(
&self,
point_in_fragment: Point2D<Au, CSSPixel>,
) -> Option<Utf32CodeUnits>
fn unmapped_character_offset( &self, point_in_fragment: Point2D<Au, CSSPixel>, ) -> Option<Utf32CodeUnits>
Like Self::character_offset, but returning the character offset in layout text (after
applying white space collapse and the text-transform property), instead of the original DOM
text.