pub(crate) struct TextFragment {
pub base: BaseFragment,
pub selected_style: ArcRefCell<Arc<ComputedValues>>,
pub font_metrics: Arc<FontMetrics>,
pub font_key: FontInstanceKey,
pub glyphs: Vec<Arc<GlyphStore>>,
pub justification_adjustment: Au,
pub offsets: Option<Box<TextRunOffsets>>,
pub is_empty_for_text_cursor: bool,
}Fields
base: BaseFragmentselected_style: ArcRefCell<Arc<ComputedValues>>font_metrics: Arc<FontMetrics>font_key: FontInstanceKeyglyphs: Vec<Arc<GlyphStore>>justification_adjustment: AuExtra space to add for each justification opportunity.
offsets: Option<Box<TextRunOffsets>>When necessary, this field store the TextRunOffsets for a particular
[TextRunLineItem]. This is currently only used inside of text inputs.
is_empty_for_text_cursor: boolWhether or not this TextFragment is an empty fragment added for the
benefit of placing a text cursor on an otherwise empty editable line.
Implementations
Sourceimpl TextFragment
impl TextFragment
pub fn print(&self, tree: &mut PrintTree)
Sourcepub(crate) fn point_is_within_vertical_boundaries(
&self,
point_in_fragment: Point2D<Au, CSSPixel>,
) -> bool
pub(crate) fn point_is_within_vertical_boundaries( &self, point_in_fragment: Point2D<Au, CSSPixel>, ) -> bool
Whether or not the given point is within the vertical boundaries of this
TextFragment.
Sourcepub(crate) fn distance_to_point_for_glyph_offset(
&self,
point_in_fragment: Point2D<Au, CSSPixel>,
) -> Au
pub(crate) fn distance_to_point_for_glyph_offset( &self, point_in_fragment: Point2D<Au, CSSPixel>, ) -> Au
Find the distance between for point relative to a TextFragment for the
purposes of finding a glyph offset. This is used to identify the most relevant
fragment for glyph offset queries during click handling.
Sourcepub(crate) fn character_offset(
&self,
point_in_fragment: Point2D<Au, CSSPixel>,
) -> Option<usize>
pub(crate) fn character_offset( &self, point_in_fragment: Point2D<Au, CSSPixel>, ) -> Option<usize>
Given a point relative to this TextFragment, find the most appropriate
character offset.
Note that the given point may be outside the TextFragment’s content rect:
- If the point is vertically above the
TextFragmentthe first offset will be returned. - If the point is vertically below the
TextFragment,Nonewill be returned.